##  Searching and Filtering for Fact Sheets
The searching and filtering capabilities for fact sheets in SAP LeanIX allow you to easily narrow down and focus on the most relevant fact sheets.
The search field in the top navigation bar helps you quickly find a specific fact sheet and jump straight to it. Clicking on the Add Filter button opens the smart search overlay. In the smart search overlay, you can do full-text searches and apply filters.
The filter panel on the left provides advanced options for applying and managing available filters. The filter groups visible on the filter panel depend on the selected fact sheet type; when you choose a specific fact sheet type, the associated filter groups are listed accordingly.
For a detailed guide on searching and filtering, see [Searching and Filtering in Inventory](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory?locale=en-US&state=PRODUCTION&version=CLOUD "Searching and filtering in the inventory helps efficiently manage your data. Learn how to quickly find fact sheets, apply filters, manage filters, and save search results for future access.").
![Searching and Filtering Capabilities in the Inventory](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio589926aa90824c949255a3c47c91ec4a_LowRes.png)
Searching and Filtering Capabilities in the Inventory
